%define courier_confdir	/etc/courier-imap
%define courier_datadir	%_datadir/courier-imap

%define confldap maildrop-ldap.conf
%define confmysql maildrop-mysql.conf


Name: maildrop
Version: 1.5.1
Release: alt1

Summary: maildrop mail filter/mail delivery agent
License: GPL
Group: Networking/Mail
Url: http://www.flounder.net/~mrsam/maildrop

Source0: %url/%name-%version.tar.bz2
Source1: %name.README-ALT
Source2: userdb.maildrop

# Fix some install paths
Patch0: %name-1.5.1-alt-makefile.patch

# remove references to mail_status from code
# because checks for this field was not implemented
#
# some mysql fixes by Egor Cheshkov <egor@iplus.ru>:
#  - possibility of using witespaces in the configure stanzas
#  - right code for use default UID/GID
#  - fix for handling 'where_clause' stanza
Patch10: %name-1.4.0-alt-mysqlfix.patch

# some configs cleanup
Patch20: %name-1.4.0-alt-config.patch

# Change name of USERDB database from userdb.dat to userdb.db
Patch30: %name-1.5.0-alt-userdb.patch

Prefix: %prefix


# Automatically added by buildreq on Sun Jan 05 2003
BuildRequires: gcc-c++ libMySQL-devel libdb4-devel libfam-devel libldap-devel libssl-devel libstdc++-devel zlib-devel

%description
Maildrop - mail delivery agent with filtering capabilities and
Maildir/Mailbox format support.

%package common
Summary: maildrop mail filtering/delivery agent - common files
Group: Networking/Mail

%description common
Maildrop is a combination mail filter/mail delivery agent.
Maildrop reads the message to be delivered to your mailbox,
optionally reads instructions from a file how filter incoming
mail, then based on these instructions may deliver mail to an
alternate mailbox, or forward it, instead of dropping the
message into your mailbox.

Maildrop uses a structured, real, meta-programming language in
order to define filtering instructions.  Its basic features are
fast and efficient.  At sites which carry a light load, the
more advanced, CPU-demanding, features can be used to build
very sophisticated mail filters.  Maildrop deployments have
been reported at sites that support as many as 30,000
mailboxes.

%package utils
Summary: maildrop mail filter/mail delivery agent - utilities
Group: Networking/Mail
Provides: courier-common-utils
Conflicts: courier-imap-utils
Requires: %name-common = %version-%release

%description utils
Some common utilities for maildrop packages.

%package userdb
Summary: maildrop mail filter/mail delivery agent with USERDB support
Group: Networking/Mail
Requires: %name-common = %version-%release, courier-common-utils

%description userdb
The %name package contains the maildrop MDA with USERDB support.
BerkleyDB database is used as source of information which required for
delivering mail to mailboxes. /etc/passwd is used as fallback
source.

%package ldap
Summary: maildrop mail filter/mail delivery agent with LDAP support
Group: Networking/Mail
Requires: %name-common = %version-%release, courier-common-utils

%description ldap
The %name package contains the maildrop MDA with LDAP support.
LDAP tree is used as source of information which required for
delivering mail to mailboxes. /etc/passwd is used as fallback
source.

%package mysql
Summary: maildrop mail filter/mail delivery agent with MySQL support
Group: Networking/Mail
Requires: %name-common = %version-%release, courier-common-utils

%description mysql
The %name package contains the maildrop MDA with MySQL support.
MySQL database is used as source of information which required for
delivering mail to mailboxes. /etc/passwd is used as fallback
source.

%package devel-static
Summary: RFC822 and RFC 2045 parsing libraries and headers files.
Group: Development/Other
#Requires: %name-common = %version-%release

%description devel-static
The %name package contains the libraries and header files for
parsing MIME (RFC2045) and e-mail messages (RFC822).

%package doc
Summary: documentation about the maildrop MDA
Group: Networking/Mail

%description doc
The %name packages contains the documentation about maildrop MDA.

%prep
%setup

%patch0 -p1
%patch10 -p1
%patch20 -p1
%patch30 -p1

%build
%configure \
  --sysconfdir=%courier_confdir \
  --with-etcdir=%courier_confdir \
  --with-makedatprog=%courier_datadir/makedatprog \
  --enable-sendmail=/usr/sbin/sendmail \
  --enable-restrict-trusted=0 \
  --enable-trusted-groups='root daemon mail postfix' \
  --enable-trusted-users='root daemon mail postfix' \
  --enable-syslog=1 \
  --enable-use-dotlock=0 \
  --enable-use-flock=0 \
  --enable-maildirquota \
  --enable-maildropldap \
  --with-ldapconfig=%courier_confdir/%confldap \
  --without-db \
  --disable-userdb

%make_build

pushd maildrop
    mv maildrop maildrop-ldap
popd
make clean

%configure \
  --sysconfdir=%courier_confdir \
  --with-etcdir=%courier_confdir \
  --with-makedatprog=%courier_datadir/makedatprog \
  --enable-sendmail=/usr/sbin/sendmail \
  --enable-restrict-trusted=0 \
  --enable-trusted-groups='root daemon mail postfix' \
  --enable-trusted-users='root daemon mail postfix' \
  --enable-syslog=1 \
  --enable-use-dotlock=0 \
  --enable-use-flock=0 \
  --enable-maildirquota \
  --enable-maildropmysql \
  --with-mysqlconfig=%courier_confdir/%confmysql \
  --without-db \
  --disable-userdb

%make_build

pushd maildrop
    mv maildrop maildrop-mysql
popd
make clean

%configure \
  --sysconfdir=%courier_confdir \
  --with-etcdir=%courier_confdir \
  --with-makedatprog=%courier_datadir/makedatprog \
  --enable-sendmail=/usr/sbin/sendmail \
  --enable-restrict-trusted=0 \
  --enable-trusted-groups='root daemon mail postfix' \
  --enable-trusted-users='root daemon mail postfix' \
  --enable-syslog=1 \
  --enable-use-dotlock=0 \
  --enable-use-flock=0 \
  --enable-maildirquota \
  --enable-userdb \
  --with-db=db \
  --with-devel

%make_build

pushd maildrop
    mv maildrop maildrop-userdb
popd

%install

# prepare dest. directory-tree
mkdir -p $RPM_BUILD_ROOT%courier_confdir
mkdir -p $RPM_BUILD_ROOT%_docdir/%name-%version/html
mkdir -p $RPM_BUILD_ROOT%_docdir/%name-%version/maildir

make DESTDIR=$RPM_BUILD_ROOT install

# install different versions of maildrop
install -D -m 0755 maildrop/maildrop-userdb $RPM_BUILD_ROOT%{_bindir}/maildrop-userdb
install -D -m 0755 maildrop/maildrop-ldap $RPM_BUILD_ROOT%{_bindir}/maildrop-ldap
install -D -m 0755 maildrop/maildrop-mysql $RPM_BUILD_ROOT%{_bindir}/maildrop-mysql

# install symlinks for some useful utilities
pushd $RPM_BUILD_ROOT%_sbindir
	ln -s ../share/courier-imap/makeuserdb makeuserdb
	ln -s ../share/courier-imap/userdb userdb
popd

# install config-files
install -D -m 0644 %SOURCE2 $RPM_BUILD_ROOT%courier_confdir/userdb
install -D -m 0644 maildir/quotawarnmsg $RPM_BUILD_ROOT%courier_confdir/quotawarnmsg.example
install -D -m 0644 maildropldap.config $RPM_BUILD_ROOT%courier_confdir/%confldap
install -D -m 0644 maildropmysql.config $RPM_BUILD_ROOT%courier_confdir/%confmysql

pushd $RPM_BUILD_ROOT%_man1dir
	ln -s maildrop.1 maildrop-userdb.1
	ln -s maildrop.1 maildrop-ldap.1
	ln -s maildrop.1 maildrop-mysql.1
popd

# adjust documentation 
#mv $RPM_BUILD_ROOT%_datadir/%name/html $RPM_BUILD_ROOT%_docdir/%name-%version
rm -rf $RPM_BUILD_ROOT%_datadir/%name/html

# maildir docs
install -m 0644 maildir/README.*.txt $RPM_BUILD_ROOT%_docdir/%name-%version/maildir
install -m 0644 maildir/README.*.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 maildir/AUTHORS $RPM_BUILD_ROOT%_docdir/%name-%version/maildir
install -m 0644 maildir/INSTALL $RPM_BUILD_ROOT%_docdir/%name-%version/maildir

# maildrop docs
install -m 0644 maildrop/README.html $RPM_BUILD_ROOT%_docdir/%name-%version/html/README.maildrop.html
install -m 0644 maildrop/mailbot.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 maildrop/maildropex.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 maildrop/maildropfilter.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 maildrop/maildropgdbm.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 maildrop/maildrop.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 maildrop/maildroptips.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 maildrop/makedat.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 maildrop/reformail.html $RPM_BUILD_ROOT%_docdir/%name-%version/html

install -m 0644 maildrop/maildrop.lsm $RPM_BUILD_ROOT%_docdir/%name-%version

# rfc2045 docs
install -m 0644 rfc2045/makemime.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 rfc2045/reformime.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 rfc2045/rfc2045.html $RPM_BUILD_ROOT%_docdir/%name-%version/html

# rfc822 docs
install -m 0644 rfc822/ChangeLog $RPM_BUILD_ROOT%_docdir/%name-%version/ChangeLog.rfc822
install -m 0644 rfc822/rfc822.html $RPM_BUILD_ROOT%_docdir/%name-%version/html

# userdb docs
install -m 0644 userdb/makeuserdb.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 userdb/userdb.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 userdb/userdbpw.html $RPM_BUILD_ROOT%_docdir/%name-%version/html

# src_root docs
install -m 0644 AUTHORS $RPM_BUILD_ROOT%_docdir/%name-%version
install -m 0644 ChangeLog $RPM_BUILD_ROOT%_docdir/%name-%version
install -m 0644 COPYING $RPM_BUILD_ROOT%_docdir/%name-%version
install -m 0644 INSTALL $RPM_BUILD_ROOT%_docdir/%name-%version
install -m 0644 NEWS $RPM_BUILD_ROOT%_docdir/%name-%version
install -m 0644 README $RPM_BUILD_ROOT%_docdir/%name-%version
install -m 0644 README.postfix $RPM_BUILD_ROOT%_docdir/%name-%version
install -m 0644 UPGRADE $RPM_BUILD_ROOT%_docdir/%name-%version
install -m 0644 maildroptips.txt $RPM_BUILD_ROOT%_docdir/%name-%version

install -m 0644 INSTALL.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 README.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 UPGRADE.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 deliverquota.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 lockmail.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 mailbot.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 maildirmake.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 maildirquota.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 maildropex.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 maildropfilter.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 maildropgdbm.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 maildrop.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 makedat.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 makemime.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 makeuserdb.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 reformail.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 reformime.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 rfc2045.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 rfc822.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 userdb.html $RPM_BUILD_ROOT%_docdir/%name-%version/html
install -m 0644 userdbpw.html $RPM_BUILD_ROOT%_docdir/%name-%version/html

install -m 0644 %SOURCE1 $RPM_BUILD_ROOT%_docdir/%name-%version

%files common
#_bindir/maildrop-overbloat
%_bindir/lockmail
%_bindir/mailbot
%_bindir/makemime
%_bindir/reformail
%_bindir/reformime
%_mandir/man1/lockmail.1*
%_mandir/man1/mailbot.1*
%_mandir/man1/maildrop.1*
%_mandir/man1/makemime.1*
%_mandir/man1/reformail.1*
%_mandir/man1/reformime.1*
%_mandir/man5/*
%_mandir/man7/*

%files userdb
%dir %courier_confdir
%config %courier_confdir/userdb
%_bindir/maildrop-userdb
%_mandir/man1/maildrop-userdb.1*
%_mandir/man1/makedat.1*
%dir %courier_datadir
%courier_datadir/makedat

%files ldap
%dir %courier_confdir
%config %courier_confdir/%confldap
%_bindir/maildrop-ldap
%_mandir/man1/maildrop-ldap.1*

%files mysql
%dir %courier_confdir
%config %courier_confdir/%confmysql
%_bindir/maildrop-mysql
%_mandir/man1/maildrop-mysql.1*

%files devel-static
%_includedir/rfc822.h
%_includedir/rfc2045.h
%_includedir/rfc2047.h
%_libdir/librfc822.a
%_libdir/librfc2045.a
%_mandir/man3/*

%files utils
# utils for maildir
%dir %courier_confdir
%config %courier_confdir/quotawarnmsg.example
%_bindir/maildirmake
%_sbindir/deliverquota
%_sbindir/makeuserdb
%_sbindir/userdb
%_sbindir/userdbpw
%_mandir/man1/maildirmake.1*
%_mandir/man8/deliverquota.8*
# utils for userdb feature
%_mandir/man8/makeuserdb.8*
%_mandir/man8/pw2userdb.8*
%_mandir/man8/userdb.8*
%_mandir/man8/userdbpw.8*
%_mandir/man8/vchkpw2userdb.8*
%dir %courier_datadir
%courier_datadir/makedatprog
%courier_datadir/makeuserdb
%courier_datadir/pw2userdb
%courier_datadir/userdb
%courier_datadir/vchkpw2userdb

%files doc
%dir %_docdir/%name-%version
%_docdir/%name-%version/*

%changelog
* Fri Jan 03 2003 Dmitry Lebkov <dlebkov@altlinux.ru> 1.5.1-alt1
- 1.5.1
- spec-file fixes

* Mon Nov 18 2002 Dmitry Lebkov <dlebkov@altlinux.ru> 1.5.0-alt2
- fix USERDB database names in the makeuserdb and related docs.

* Fri Oct 25 2002 Dmitry Lebkov <dlebkov@altlinux.ru> 1.5.0-alt1
- 1.5.0
- some spec-file fixes

* Mon Oct 14 2002 Dmitry Lebkov <dlebkov@altlinux.ru> 1.4.0-alt2
- some fixes in the mysql driver code.

* Wed Sep 11 2002 Dmitry Lebkov <dlebkov@altlinux.ru> 1.4.0-alt1
- initial package for ALT Linux
